Package: likelihood.model
Type: Package
Title: Likelihood-Based Statistical Inference in the Fisherian
        Tradition
Version: 1.0.1
Authors@R: 
    person("Alexander", "Towell", , "lex@metafunctor.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0001-6443-9897"))
Description: Facilitates building likelihood models in the Fisherian tradition
    following Richard Royall (1997, ISBN:978-0412044113) "Statistical Evidence: A
    Likelihood Paradigm". Defines generic methods for working with likelihoods
    (loglik(), score(), hess_loglik(), fim()) and provides functions for pure
    likelihood-based inference (support(), relative_likelihood(),
    likelihood_interval(), profile_loglik()).
License: MIT + file LICENSE
Encoding: UTF-8
Depends: algebraic.mle (>= 2.0.0)
Imports: algebraic.dist, generics, stats, numDeriv, boot
URL: https://github.com/queelius/likelihood.model,
        https://queelius.github.io/likelihood.model/
BugReports: https://github.com/queelius/likelihood.model/issues
Suggests: mvtnorm, testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-24 08:17:51 UTC; spinoza
Author: Alexander Towell [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6443-9897>)
Maintainer: Alexander Towell <lex@metafunctor.com>
Repository: CRAN
Date/Publication: 2026-05-24 09:20:02 UTC
Built: R 4.5.2; ; 2026-05-24 13:51:37 UTC; unix
