# Generated by roxygen2: do not edit by hand

S3method(assumptions,exponential_lifetime)
S3method(bias,fisher_boot)
S3method(bias,fisher_mle)
S3method(coef,fisher_mle)
S3method(confint,fisher_boot)
S3method(confint,fisher_mle)
S3method(deviance,fisher_mle)
S3method(evidence,likelihood_model)
S3method(fim,exponential_lifetime)
S3method(fim,likelihood_model)
S3method(fit,exponential_lifetime)
S3method(fit,likelihood_model)
S3method(hess_loglik,exponential_lifetime)
S3method(hess_loglik,likelihood_model)
S3method(likelihood_interval,fisher_mle)
S3method(logLik,fisher_mle)
S3method(loglik,exponential_lifetime)
S3method(loglik,likelihood_model)
S3method(mse,fisher_mle)
S3method(nobs,fisher_mle)
S3method(nparams,fisher_mle)
S3method(obs,fisher_mle)
S3method(observed_fim,fisher_mle)
S3method(params,fisher_mle)
S3method(print,fisher_boot)
S3method(print,fisher_mle)
S3method(print,likelihood_interval)
S3method(print,likelihood_model)
S3method(print,lrt_result)
S3method(print,profile_loglik)
S3method(print,summary_fisher_mle)
S3method(profile_loglik,fisher_mle)
S3method(rdata,exponential_lifetime)
S3method(rdata,likelihood_model)
S3method(relative_likelihood,fisher_mle)
S3method(sampler,fisher_boot)
S3method(sampler,fisher_mle)
S3method(sampler,likelihood_model)
S3method(score,exponential_lifetime)
S3method(score,likelihood_model)
S3method(score_val,fisher_mle)
S3method(se,fisher_mle)
S3method(summary,fisher_mle)
S3method(support,fisher_mle)
S3method(vcov,fisher_mle)
export(assumptions)
export(evidence)
export(exponential_lifetime)
export(fim)
export(fisher_boot)
export(fisher_mle)
export(fit)
export(hess_loglik)
export(is_likelihood_model)
export(likelihood_interval)
export(loglik)
export(lrt)
export(profile_loglik)
export(rdata)
export(relative_likelihood)
export(score)
export(support)
importFrom(algebraic.dist,nparams)
importFrom(algebraic.dist,obs)
importFrom(algebraic.dist,params)
importFrom(algebraic.dist,sampler)
importFrom(algebraic.mle,bias)
importFrom(algebraic.mle,mse)
importFrom(algebraic.mle,observed_fim)
importFrom(algebraic.mle,score_val)
importFrom(algebraic.mle,se)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(generics,fit)
importFrom(numDeriv,grad)
importFrom(numDeriv,hessian)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,cov)
importFrom(stats,nobs)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,printCoefmat)
importFrom(stats,qnorm)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,uniroot)
importFrom(stats,vcov)
importFrom(utils,modifyList)
