% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fit.R
\name{fit}
\alias{fit}
\title{Fit a model}
\description{
Re-exported from \pkg{generics}. See \code{\link[generics:fit]{generics::fit()}} for details.
}
