% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/example-exponential.R
\name{rdata.exponential_lifetime}
\alias{rdata.exponential_lifetime}
\title{Random data generation for exponential_lifetime}
\usage{
\method{rdata}{exponential_lifetime}(model, ...)
}
\arguments{
\item{model}{An exponential_lifetime model}

\item{...}{Additional arguments (ignored)}
}
\value{
A function(theta, n, censor_time, ...) that returns a data frame
}
\description{
Generates exponential data, optionally with right-censoring at a fixed
censoring time.
}
