% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{fisher_boot}
\alias{fisher_boot}
\title{Bootstrap MLE Estimate}
\usage{
fisher_boot(boot_result, original_mle)
}
\arguments{
\item{boot_result}{Result from boot::boot()}

\item{original_mle}{The original fisher_mle object}
}
\value{
An object of class \code{c("fisher_boot", "fisher_mle", "mle_fit", "boot")}
}
\description{
Creates a \code{fisher_boot} object representing bootstrap-based inference
for maximum likelihood estimates.
}
