% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{sampler.fisher_mle}
\alias{sampler.fisher_mle}
\title{Asymptotic sampler for fisher_mle}
\usage{
\method{sampler}{fisher_mle}(x, ...)
}
\arguments{
\item{x}{A fisher_mle object}

\item{...}{Additional arguments (ignored)}
}
\value{
Function that takes n and returns n x p matrix of samples
}
\description{
Returns a function that samples from the asymptotic normal distribution
of the MLE: N(theta_hat, vcov).
}
