% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{score_val.fisher_mle}
\alias{score_val.fisher_mle}
\title{Extract score vector from fisher_mle}
\usage{
\method{score_val}{fisher_mle}(x, ...)
}
\arguments{
\item{x}{A fisher_mle object}

\item{...}{Additional arguments (ignored)}
}
\value{
The score vector at the MLE (should be near zero)
}
\description{
Extract score vector from fisher_mle
}
