% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{sampler.fisher_boot}
\alias{sampler.fisher_boot}
\title{Bootstrap sampler for fisher_boot}
\usage{
\method{sampler}{fisher_boot}(x, ...)
}
\arguments{
\item{x}{A fisher_boot object}

\item{...}{Additional arguments (ignored)}
}
\value{
Function that takes n and returns n x p matrix of resampled estimates
}
\description{
Returns a function that resamples from the bootstrap distribution.
}
