% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{obs.fisher_mle}
\alias{obs.fisher_mle}
\title{Extract observed data from fisher_mle}
\usage{
\method{obs}{fisher_mle}(x)
}
\arguments{
\item{x}{A fisher_mle object}
}
\value{
Always \code{NULL}. \code{fisher_mle} objects do not store the observed data.
}
\description{
\code{fisher_mle} objects do not store observed data by design, so this
always returns NULL.
}
