% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-lrt.R
\name{print.lrt_result}
\alias{print.lrt_result}
\title{Print method for likelihood ratio test results}
\usage{
\method{print}{lrt_result}(x, ...)
}
\arguments{
\item{x}{An lrt_result object}

\item{...}{Additional arguments (ignored)}
}
\value{
The lrt_result object, invisibly
}
\description{
Print method for likelihood ratio test results
}
