% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisherian.R
\name{print.profile_loglik}
\alias{print.profile_loglik}
\title{Print profile log-likelihood}
\usage{
\method{print}{profile_loglik}(x, ...)
}
\arguments{
\item{x}{A profile_loglik object}

\item{...}{Additional arguments (ignored)}
}
\value{
The profile_loglik object, invisibly
}
\description{
Print profile log-likelihood
}
