% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{se.fisher_mle}
\alias{se.fisher_mle}
\title{Extract standard errors from fisher_mle}
\usage{
\method{se}{fisher_mle}(x, ...)
}
\arguments{
\item{x}{A fisher_mle object}

\item{...}{Additional arguments (ignored)}
}
\value{
Numeric vector of standard errors, or NA values if vcov is NULL
}
\description{
Computes standard errors as the square root of the diagonal
of the variance-covariance matrix.
}
