% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-fisher_mle.R
\name{bias.fisher_boot}
\alias{bias.fisher_boot}
\title{Compute bootstrap bias estimate}
\usage{
\method{bias}{fisher_boot}(x, theta = NULL, ...)
}
\arguments{
\item{x}{A fisher_boot object}

\item{theta}{Ignored (for compatibility)}

\item{...}{Additional arguments (ignored)}
}
\value{
Bias estimate vector
}
\description{
Estimates bias from bootstrap replicates:
bias = mean(bootstrap estimates) - original estimate
}
