% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/core-generics.R
\name{loglik.likelihood_model}
\alias{loglik.likelihood_model}
\title{Default loglik method}
\usage{
\method{loglik}{likelihood_model}(model, ...)
}
\arguments{
\item{model}{A likelihood model}

\item{...}{Additional arguments}
}
\value{
Never returns; always errors.
}
\description{
Provides a clear error when a model class does not implement \code{loglik}.
}
