% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/example-exponential.R
\name{fim.exponential_lifetime}
\alias{fim.exponential_lifetime}
\title{Fisher information matrix for exponential_lifetime}
\usage{
\method{fim}{exponential_lifetime}(model, ...)
}
\arguments{
\item{model}{An exponential_lifetime model}

\item{...}{Additional arguments (ignored)}
}
\value{
A function(theta, n_obs, ...) computing the FIM
}
\description{
Returns the analytical FIM: n / lambda^2 (1x1 matrix).
}
